# laskea

Calculate (Finnish: laskea) some parts.

Third party dependencies are documented in the folder [docs/third-party](docs/third-party/README.md).

## Status

Experimental.

[License: MIT](https://github.com/sthagen/laskea/blob/default/LICENSE)

[![version](https://img.shields.io/pypi/v/laskea.svg?style=flat)](https://pypi.python.org/pypi/laskea/)
[![downloads](https://pepy.tech/badge/laskea/month)](https://pepy.tech/project/laskea)
[![wheel](https://img.shields.io/pypi/wheel/laskea.svg?style=flat)](https://pypi.python.org/pypi/laskea/)
[![supported-versions](https://img.shields.io/pypi/pyversions/laskea.svg?style=flat)](https://pypi.python.org/pypi/laskea/)
[![supported-implementations](https://img.shields.io/pypi/implementation/laskea.svg?style=flat)](https://pypi.python.org/pypi/laskea/)

**Note**: The default branch is `default`.
